@@ -14,21 +14,31 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-from __future__ import absolute_import
+from typing import TYPE_CHECKING
 
-from .. import (
-    config,
-    errors,
-    controldir,
-    pyutils,
-    registry,
-    )
+from .. import config, controldir, errors, pyutils, registry
+from .. import transport as _mod_transport
+from ..branch import format_registry as branch_format_registry
+from ..repository import format_registry as repository_format_registry
+from ..workingtree import format_registry as workingtree_format_registry
+
+if TYPE_CHECKING:
+    from .bzrdir import BzrDirFormat
+
+
+class LineEndingError(errors.BzrError):
+
+    _fmt = ("Line ending corrupted for file: %(file)s; "
+            "Maybe your files got corrupted in transport?")
+
+    def __init__(self, file):
+        self.file = file
 
 
 class BzrProber(controldir.Prober):
     """Prober for formats that use a .bzr/ control directory."""
 
-    formats = registry.FormatRegistry(controldir.network_format_registry)
+    formats = registry.FormatRegistry["BzrDirFormat"](controldir.network_format_registry)
     """The known .bzr formats."""
 
     @classmethod
@@ -40,17 +50,27 @@ class BzrProber(controldir.Prober):
         """Return the .bzrdir style format present in a directory."""
         try:
             format_string = transport.get_bytes(".bzr/branch-format")
-        except errors.NoSuchFile:
+        except _mod_transport.NoSuchFile:
             raise errors.NotBranchError(path=transport.base)
+        except errors.BadHttpRequest as e:
+            if e.reason == 'no such method: .bzr':
+                # hgweb
+                raise errors.NotBranchError(path=transport.base)
+            raise
+
         try:
             first_line = format_string[:format_string.index(b"\n") + 1]
         except ValueError:
             first_line = format_string
+        if (first_line.startswith(b'<!DOCTYPE') or
+                first_line.startswith(b'<html')):
+            raise errors.NotBranchError(
+                path=transport.base, detail="format file looks like HTML")
         try:
             cls = klass.formats.get(first_line)
         except KeyError:
             if first_line.endswith(b"\r\n"):
-                raise errors.LineEndingError(file=".bzr/branch-format")
+                raise LineEndingError(file=".bzr/branch-format")
             else:
                 raise errors.UnknownFormatError(
                     format=first_line, kind='bzrdir')
@@ -147,7 +167,7 @@ def register_metadir(registry, key,
         try:
             factory = pyutils.get_named_object(mod_name, factory_name)
         except ImportError as e:
-            raise ImportError('failed to load %s: %s' % (full_name, e))
+            raise ImportError('failed to load {}: {}'.format(full_name, e))
         except AttributeError:
             raise AttributeError('no factory %s in module %r'
                                  % (full_name, sys.modules[mod_name]))
@@ -166,6 +186,126 @@ def register_metadir(registry, key,
                       experimental)
 
 
+# formats which have no format string are not discoverable
+# and not independently creatable, so are not registered.
+branch_format_registry.register_lazy(
+    b"Bazaar-NG branch format 5\n", "breezy.bzr.fullhistory",
+    "BzrBranchFormat5")
+branch_format_registry.register_lazy(
+    b"Bazaar Branch Format 6 (bzr 0.15)\n",
+    "breezy.bzr.branch", "BzrBranchFormat6")
+branch_format_registry.register_lazy(
+    b"Bazaar Branch Format 7 (needs bzr 1.6)\n",
+    "breezy.bzr.branch", "BzrBranchFormat7")
+branch_format_registry.register_lazy(
+    b"Bazaar Branch Format 8 (needs bzr 1.15)\n",
+    "breezy.bzr.branch", "BzrBranchFormat8")
+branch_format_registry.register_lazy(
+    b"Bazaar-NG Branch Reference Format 1\n",
+    "breezy.bzr.branch", "BranchReferenceFormat")
+
+branch_format_registry.set_default_key(b"Bazaar Branch Format 7 (needs bzr 1.6)\n")
+
+
+# formats which have no format string are not discoverable or independently
+# creatable on disk, so are not registered in format_registry.  They're
+# all in breezy.bzr.knitreponow.  When an instance of one of these is
+# needed, it's constructed directly by the ControlDir.  Non-native formats where
+# the repository is not separately opened are similar.
+
+repository_format_registry.register_lazy(
+    b'Bazaar-NG Knit Repository Format 1',
+    'breezy.bzr.knitrepo',
+    'RepositoryFormatKnit1',
+    )
+
+repository_format_registry.register_lazy(
+    b'Bazaar Knit Repository Format 3 (bzr 0.15)\n',
+    'breezy.bzr.knitrepo',
+    'RepositoryFormatKnit3',
+    )
+
+repository_format_registry.register_lazy(
+    b'Bazaar Knit Repository Format 4 (bzr 1.0)\n',
+    'breezy.bzr.knitrepo',
+    'RepositoryFormatKnit4',
+    )
+
+# Pack-based formats. There is one format for pre-subtrees, and one for
+# post-subtrees to allow ease of testing.
+# NOTE: These are experimental in 0.92. Stable in 1.0 and above
+repository_format_registry.register_lazy(
+    b'Bazaar pack repository format 1 (needs bzr 0.92)\n',
+    'breezy.bzr.knitpack_repo',
+    'RepositoryFormatKnitPack1',
+    )
+repository_format_registry.register_lazy(
+    b'Bazaar pack repository format 1 with subtree support (needs bzr 0.92)\n',
+    'breezy.bzr.knitpack_repo',
+    'RepositoryFormatKnitPack3',
+    )
+repository_format_registry.register_lazy(
+    b'Bazaar pack repository format 1 with rich root (needs bzr 1.0)\n',
+    'breezy.bzr.knitpack_repo',
+    'RepositoryFormatKnitPack4',
+    )
+repository_format_registry.register_lazy(
+    b'Bazaar RepositoryFormatKnitPack5 (bzr 1.6)\n',
+    'breezy.bzr.knitpack_repo',
+    'RepositoryFormatKnitPack5',
+    )
+repository_format_registry.register_lazy(
+    b'Bazaar RepositoryFormatKnitPack5RichRoot (bzr 1.6.1)\n',
+    'breezy.bzr.knitpack_repo',
+    'RepositoryFormatKnitPack5RichRoot',
+    )
+repository_format_registry.register_lazy(
+    b'Bazaar RepositoryFormatKnitPack5RichRoot (bzr 1.6)\n',
+    'breezy.bzr.knitpack_repo',
+    'RepositoryFormatKnitPack5RichRootBroken',
+    )
+repository_format_registry.register_lazy(
+    b'Bazaar RepositoryFormatKnitPack6 (bzr 1.9)\n',
+    'breezy.bzr.knitpack_repo',
+    'RepositoryFormatKnitPack6',
+    )
+repository_format_registry.register_lazy(
+    b'Bazaar RepositoryFormatKnitPack6RichRoot (bzr 1.9)\n',
+    'breezy.bzr.knitpack_repo',
+    'RepositoryFormatKnitPack6RichRoot',
+    )
+repository_format_registry.register_lazy(
+    b'Bazaar repository format 2a (needs bzr 1.16 or later)\n',
+    'breezy.bzr.groupcompress_repo',
+    'RepositoryFormat2a',
+    )
+
+# Development formats.
+# Check their docstrings to see if/when they are obsolete.
+repository_format_registry.register_lazy(
+    (b"Bazaar development format 2 with subtree support "
+        b"(needs bzr.dev from before 1.8)\n"),
+    'breezy.bzr.knitpack_repo',
+    'RepositoryFormatPackDevelopment2Subtree',
+    )
+repository_format_registry.register_lazy(
+    b'Bazaar development format 8\n',
+    'breezy.bzr.groupcompress_repo',
+    'RepositoryFormat2aSubtree',
+    )
+
+
+workingtree_format_registry.register_lazy(b"Bazaar Working Tree Format 4 (bzr 0.15)\n",
+                              "breezy.bzr.workingtree_4", "WorkingTreeFormat4")
+workingtree_format_registry.register_lazy(b"Bazaar Working Tree Format 5 (bzr 1.11)\n",
+                              "breezy.bzr.workingtree_4", "WorkingTreeFormat5")
+workingtree_format_registry.register_lazy(b"Bazaar Working Tree Format 6 (bzr 1.14)\n",
+                              "breezy.bzr.workingtree_4", "WorkingTreeFormat6")
+workingtree_format_registry.register_lazy(b"Bazaar-NG Working Tree format 3",
+                              "breezy.bzr.workingtree_3", "WorkingTreeFormat3")
+workingtree_format_registry.set_default_key(b"Bazaar Working Tree Format 6 (bzr 1.14)\n")
+
+
 register_metadir(
     controldir.format_registry, 'knit',
     'breezy.bzr.knitrepo.RepositoryFormatKnit1',
@@ -197,7 +337,7 @@ register_metadir(
     controldir.format_registry, 'rich-root',
     'breezy.bzr.knitrepo.RepositoryFormatKnit4',
     help='Variant of dirstate with better handling of tree roots. '
-    'Introduced in bzr 1.0',
+    'Introduced in bzr 1.0.',
     branch_format='breezy.bzr.branch.BzrBranchFormat6',
     tree_format='breezy.bzr.workingtree_4.WorkingTreeFormat4',
     hidden=True,
@@ -210,6 +350,7 @@ register_metadir(
     branch_format='breezy.bzr.branch.BzrBranchFormat6',
     tree_format='breezy.bzr.workingtree_4.WorkingTreeFormat4',
     experimental=True,
+    deprecated=True,
     hidden=True,
     )
 register_metadir(
@@ -217,7 +358,7 @@ register_metadir(
     'breezy.bzr.knitpack_repo.RepositoryFormatKnitPack1',
     help='Pack-based format used in 1.x series. Introduced in 0.92. '
     'Interoperates with bzr repositories before 0.92 but cannot be '
-    'read by bzr < 0.92. ',
+    'read by bzr < 0.92.',
     branch_format='breezy.bzr.branch.BzrBranchFormat6',
     tree_format='breezy.bzr.workingtree_4.WorkingTreeFormat4',
     deprecated=True,
@@ -228,7 +369,7 @@ register_metadir(
     'breezy.bzr.knitpack_repo.RepositoryFormatKnitPack3',
     help='Pack-based format used in 1.x series, with subtree support. '
     'Introduced in 0.92. Interoperates with '
-    'bzr repositories before 0.92 but cannot be read by bzr < 0.92. ',
+    'bzr repositories before 0.92 but cannot be read by bzr < 0.92.',
     branch_format='breezy.bzr.branch.BzrBranchFormat6',
     tree_format='breezy.bzr.workingtree_4.WorkingTreeFormat4',
     hidden=True,
@@ -319,6 +460,7 @@ register_metadir(
     branch_format='breezy.bzr.branch.BzrBranchFormat8',
     tree_format='breezy.bzr.workingtree_4.WorkingTreeFormat6',
     experimental=True,
+    deprecated=True,
     hidden=True,
     )
 register_metadir(
@@ -333,6 +475,7 @@ register_metadir(
     branch_format='breezy.bzr.branch.BzrBranchFormat7',
     tree_format='breezy.bzr.workingtree_4.WorkingTreeFormat6',
     experimental=True,
+    deprecated=True,
     hidden=True,
     )
 
@@ -357,6 +500,7 @@ register_metadir(controldir.format_registry, '2a',
                  branch_format='breezy.bzr.branch.BzrBranchFormat7',
                  tree_format='breezy.bzr.workingtree_4.WorkingTreeFormat6',
                  experimental=False,
+                 deprecated=False,
                  )
 
 # The following format should be an alias for the rich root equivalent
