@@ -19,10 +19,8 @@
 
 """Some functions to enable caching the conversion between unicode to utf8"""
 
-from codecs import (
-    utf_8_encode as _utf8_encode,
-    utf_8_decode as _utf8_decode,
-)
+from codecs import utf_8_decode as _utf8_decode
+from codecs import utf_8_encode as _utf8_encode
 from typing import Dict
 
 
