@@ -19,12 +19,7 @@
 import re
 from typing import Optional, Type
 
-from . import (
-    errors,
-    hooks,
-    registry,
-    urlutils,
-    )
+from . import errors, hooks, registry, urlutils
 
 
 class NoSuchProject(errors.BzrError):
@@ -134,6 +129,12 @@ class MergeProposal:
     def __init__(self, url=None):
         self.url = url
 
+    def __str__(self):
+        return self.url
+
+    def __repr__(self):
+        return "<%s(%r)>" % (self.__class__.__name__, self.url)
+
     def get_web_url(self):
         raise NotImplementedError(self.get_web_url)
 
@@ -416,7 +417,7 @@ class Forge:
         """
         raise NotImplementedError(self.delete_project)
 
-    def create_project(self, name):
+    def create_project(self, name, summary=None):
         """Create a project.
         """
         raise NotImplementedError(self.create_project)
@@ -519,7 +520,7 @@ def get_proposal_by_url(url):
     raise UnsupportedForge(url)
 
 
-def create_project(url: str) -> None:
+def create_project(url: str, *, summary=None) -> None:
     """Create a project.
 
     Args:
@@ -533,7 +534,7 @@ def create_project(url: str) -> None:
         except UnsupportedForge:
             pass
         else:
-            hoster.create_project(parsed_url.path)
+            hoster.create_project(parsed_url.path, summary=summary)
             break
     else:
         raise UnsupportedForge(url)
