@@ -16,20 +16,14 @@
 
 """Test for git server."""
 
-from dulwich.client import TCPGitClient
-from dulwich.repo import Repo
 import threading
 
-from ...transport import transport_server_registry
-from ...tests import (
-    TestCase,
-    TestCaseWithTransport,
-    )
+from dulwich.client import TCPGitClient
+from dulwich.repo import Repo
 
-from ..server import (
-    BzrBackend,
-    BzrTCPGitServer,
-    )
+from ...tests import TestCase, TestCaseWithTransport
+from ...transport import transport_server_registry
+from ..server import BzrBackend, BzrTCPGitServer
 
 
 class TestPresent(TestCase):
@@ -66,7 +60,7 @@ class TestPlainFetch(GitServerTestCase):
         result = c.fetch('/', gitrepo)
         self.assertEqual(
             set(result.refs.keys()),
-            set([b"refs/tags/atag", b'refs/heads/master', b"HEAD"]))
+            {b"refs/tags/atag", b'refs/heads/master', b"HEAD"})
 
     def test_fetch_nothing(self):
         wt = self.make_branch_and_tree('t')
@@ -81,7 +75,7 @@ class TestPlainFetch(GitServerTestCase):
         result = c.fetch('/', gitrepo, determine_wants=lambda x: [])
         self.assertEqual(
             set(result.refs.keys()),
-            set([b"refs/tags/atag", b"HEAD"]))
+            {b"refs/tags/atag", b"HEAD"})
 
     def test_fetch_from_non_git(self):
         wt = self.make_branch_and_tree('t', format='bzr')
@@ -96,4 +90,4 @@ class TestPlainFetch(GitServerTestCase):
         result = c.fetch('/', gitrepo)
         self.assertEqual(
             set(result.refs.keys()),
-            set([b"refs/tags/atag", b"HEAD"]))
+            {b"refs/tags/atag", b"HEAD"})
