@@ -16,24 +16,11 @@
 
 """Classes to provide name-to-object registry-like support."""
 
-from typing import (
-    TypeVar,
-    Generic,
-    Optional,
-    Any,
-    cast,
-    Union,
-    Callable,
-    Dict,
-    List,
-    Iterator,
-    Tuple,
-    Callable,
-)
+from typing import (Any, Callable, Dict, Generic, Iterator, List, Optional,
+                    Tuple, TypeVar, Union, cast)
 
 from .pyutils import get_named_object
 
-
 T = TypeVar('T')
 
 
