@@ -16,14 +16,9 @@
 
 """Tests for repository revision signatures."""
 
-from breezy import (
-    errors,
-    gpg,
-    tests,
-    urlutils,
-    )
-from breezy.repository import WriteGroup
+from breezy import errors, gpg, tests, urlutils
 from breezy.bzr.testament import Testament
+from breezy.repository import WriteGroup
 from breezy.tests import per_repository
 
 
