@@ -17,19 +17,15 @@
 """Tests for breezy.export."""
 
 import gzip
-from io import BytesIO
 import os
 import tarfile
 import time
 import zipfile
+from io import BytesIO
 
-from .. import (
-    errors,
-    export,
-    tests,
-    )
-from ..export import get_root_name
+from .. import errors, export, tests
 from ..archive.tar import tarball_generator
+from ..export import get_root_name
 from . import features
 
 
@@ -50,7 +46,7 @@ class TestDirExport(tests.TestCaseWithTransport):
         self.assertEqual([], os.listdir("target"))
 
     def test_symlink(self):
-        self.requireFeature(features.SymlinkFeature)
+        self.requireFeature(features.SymlinkFeature(self.test_dir))
         wt = self.make_branch_and_tree('.')
         os.symlink('source', 'link')
         wt.add(['link'])
