@@ -14,19 +14,11 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-from breezy import (
-    branch as _mod_branch,
-    controldir,
-    errors,
-    reconfigure,
-    repository,
-    tests,
-    workingtree,
-    )
-from breezy.bzr import (
-    branch as _mod_bzrbranch,
-    vf_repository,
-    )
+from breezy import branch as _mod_branch
+from breezy import (controldir, errors, reconfigure, repository, tests,
+                    workingtree)
+from breezy.bzr import branch as _mod_bzrbranch
+from breezy.bzr import vf_repository
 
 
 class TestReconfigure(tests.TestCaseWithTransport):
@@ -461,10 +453,10 @@ class TestReconfigure(tests.TestCaseWithTransport):
         format = controldir.format_registry.make_controldir('1.9')
         format.set_branch_format(_mod_bzrbranch.BzrBranchFormat8())
         tree = self.make_branch_and_tree('tree', format=format)
-        tree.branch.set_reference_info('path', '../location', 'file_id')
+        tree.branch.set_reference_info(b'file_id', '../location', 'path')
         checkout = tree.branch.create_checkout('checkout', lightweight=True)
         reconfiguration = reconfigure.Reconfigure.to_tree(checkout.controldir)
         reconfiguration.apply()
         checkout_branch = checkout.controldir.open_branch()
-        self.assertEqual(('../location', b'file_id'),
-                         checkout_branch.get_reference_info('path'))
+        self.assertEqual(('../location', 'path'),
+                         checkout_branch.get_reference_info(b'file_id'))
